@@ -62,16 +62,13 @@ And in comparison with C<Mojo::AsyncAwait>, it's it's more intuitive how to use
 
 The instance of this class can work only with one domain and scheme: either HTTP or HTTPS.
 
-This package uses C<Time:HiRes> library. But the last one currently doesn't support Win32 platform.
-It means that this package won't work on Win32 too.
-
 =head1 LICENSE
 
 This module is distributed under terms of Artistic Perl 5 license.
 
 =cut
 
-use 5.026;
+use 5.020;
 use warnings;
 use bytes ();
 use Socket qw/ inet_aton pack_sockaddr_in AF_INET SOCK_STREAM SOL_SOCKET SO_KEEPALIVE SO_OOBINLINE IPPROTO_TCP TCP_KEEPIDLE TCP_KEEPINTVL TCP_KEEPCNT /;
@@ -80,7 +77,7 @@ use Fcntl qw/ F_SETFL O_NONBLOCK FD_CLOEXEC /;
 use experimental qw/ signatures /;
 use Carp qw/ croak /;
 use List::Util qw/ first /;
-use Time::HiRes qw/ alarm time sleep /;
+use Time::HiRes qw/ time /;
 use Mojo::Message::Request ();
 use Mojo::Message::Response ();
 use Mojo::Transaction::HTTP ();
@@ -88,7 +85,7 @@ use URI ();
 use Scalar::Util qw/ blessed /;
 use Errno qw / :POSIX /;
 
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 
 =head2 new($class, %opts)
 
@@ -125,7 +122,7 @@ See C<IO::Socket::SSL> constructor arguments for details.
 =item connect_timeout
 
 By default it's equal to 1.
-Sets connection timeout in seconds (can be float with micro seconds accuracy).
+Sets connection timeout in seconds.
 
 If it's equal to 0, then there will be no timeout restrictions.
 
@@ -626,7 +623,7 @@ sub wait_for_next_response ($self, $timeout = 0) {
     while (1) {
         last if ($exp_ts && time() >= $exp_ts); # awaiting process is time-outed
         last if (($response = $self->next_response()) || !$self->not_empty());
-        sleep(1E-6) if (!$response); # sleep 1 microsecond
+        select(undef, undef, undef, 1E-6) if (!$response); # sleep 1 microsecond
     }
 
     return $response;
